This is sub-crate of captains-log
Provides a attribute macro logfn to wrap function for convenience.
Attribute Macros
- logfn
- Provide an proc_macro
#[logfn]which log the information:
This is sub-crate of captains-log
Provides a attribute macro logfn to wrap function for convenience.
#[logfn] which log the information: